libxfce4kbd-private-sys 0.2.0+dev

FFI bindings to libxfce4kbd-private
libxfce4kbd-private-sys-0.2.0+dev has been yanked.

libxfce4kbd-private-sys

This crate provides FFI bindings for libxfce4kbd-private, which is a utility library for handling keyboard shortcuts for Xfce. The underlying C library is intended to be for private use only by Xfce components, and its API and ABI are subject to change without considerations for backward-compatibility. Do not use this crate.